@@ -1,11 +1,10 @@
-
-__author__ = 'Pavel Maksimov'
-__email__ = 'vur21@ya.com'
-__version__ = '2021.2.21'
+__author__ = "Pavel Maksimov"
+__email__ = "vur21@ya.ru"
+__version__ = "2021.5.27"
 
 from .resource_mapping import *
 from .tapi_yandex_metrika import (
     YandexMetrikaStats,
     YandexMetrikaLogsapi,
-    YandexMetrikaManagement
+    YandexMetrikaManagement,
 )
